@@ -87,7 +87,7 @@ buildbam <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('o
 #' # First, order the terms based on Wilks' Lambda
 #' m <- buildcustom(changed ~ friends.nl+friends.be+multilingual+standard+hearing+reading+attention+
 #' sleep+gender+handedness+diglossic+age+years,direction='order',fit=flipfit,crit=crit.Wilks)
-#' # Now, use the six most importFromant terms (arbitrary choice) in the LDA
+#' # Now, use the six most important terms (arbitrary choice) in the LDA
 #' library(MASS)
 #' m <- lda(changed ~ diglossic + age + reading + friends.be + years + multilingual,data=migrant)
 #' @template seealso
@@ -495,7 +495,7 @@ buildmertree <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=
 		left <- as.character(terms[2])
 		if (is.null(lme4::findbars(terms[[3]]))) stop('Error: no random effects found in the middle block of the glmertree formula. Use the following format: dep ~ offset terms | random-effect terms | partitioning variables, where the random effects are specified in lme4 form, e.g. dep ~ a | (1|b) + (1|c) | d.')
 		middle <- as.character(terms[3])
-		formula <- stats::reformulate(middle,dep)
+		formula <- stats::as.formula(paste0(dep,'~',paste0(middle,collapse='+')),env=parent.frame())
 	} else {
 		left <- as.character(left[2])
 		right <- as.character(right[2])
